@@ -14,19 +14,26 @@ setup(
         'cli',
         'cli.tester',
         'dsframework',
-        'dsframework.base_classes',
-        'dsframework.config',
-        'dsframework.pipeline',
-        'dsframework.shared',
-        'dsframework.utils',
-        'dsframework.testable',
+        'dsframework.base',
+        'dsframework.base.common',
+        'dsframework.base.pipeline',
+        'dsframework.base.pipeline.artifacts',
+        'dsframework.base.pipeline.forcers',
+        'dsframework.base.pipeline.postprocessor',
+        'dsframework.base.pipeline.predictables',
+        'dsframework.base.pipeline.predictors',
+        'dsframework.base.pipeline.preprocessor',
+        'dsframework.base.server',
+        'dsframework.base.testable',
+        'dsframework.base.tester',
+        'dsframework.base.trainer',
     ],
-    package_data={'': ['config.yaml']},
+    package_data={'': ['config.json']},
     entry_points='''
         [console_scripts]
         ds-framework-cli=api_cli:cli
     ''',
-    version='0.1.15',
+    version='0.1.16',
     description='My first Python library',
     # url='http://pypi.python.org/pypi/PackageName/',
     author='oribrau@gmail.com',
